---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is. Please try to include all relevant information that you have (NCrystal version, OS, compiler version, how are you using NCrystal, how can we reproduce, etc.).
